@@ -44,10 +44,11 @@ class AutoFeat(object):
         for col in tqdm(self.normalize_entity_cols, desc='Normalize Entity'):
             self.es.normalize_entity(self.entity_id, col, col)
 
-    def run_dfs(self, max_depth=1, features_only=True, chunk_size=None, n_jobs=1, ignore_variables=None):
+    def run_dfs(self, max_depth=1, features_only=True, chunk_size=None, n_jobs=1, ignore_variables=None,
+                reduce_mem=True, **kwargs):
         """Deep Feature Synthesis"""
         if ignore_variables is None:
-            ignore_variables = [self.target_entity_id]  # ['uid']
+            ignore_variables = [self.target_entity_id, self.index]  #
 
         _ = ft.dfs(
             entityset=self.es,
@@ -58,15 +59,18 @@ class AutoFeat(object):
             chunk_size=chunk_size,
             n_jobs=n_jobs,
             verbose=1,
+            **kwargs
         )
 
         if features_only:
             return _
         else:
             df_ = _[0].add_prefix(f'{self.entity_id}_').reset_index()
-            df_ = reduce_mem_usage(df_)
             df_ = remove_low_information_features(df_)
 
+            if reduce_mem:
+                df_ = reduce_mem_usage(df_)
+
             return df_
 
     @property
@@ -103,7 +107,6 @@ if __name__ == '__main__':
         vt.Categorical: ['a', 'b']
     }
 
-    af = AutoFeat(df, 'test', 'test', type2features)
-    # af = AutoFeat(df, 'test', type2features, index='uid')  # base_entity 就是 base_entity_id
+    af = AutoFeat(df, 'test', 'test', type2features, index='uid')  # base_entity 就是 base_entity_id
 
-    af.run_dfs(max_depth=2)
+    print(af.run_dfs(max_depth=2))  # print(af.run_dfs(max_depth=2, ignore_variables=['uid']))
