@@ -17,10 +17,11 @@ from sklearn.model_selection import StratifiedKFold
 
 class BaseOOF(object):
 
-    def __init__(self, X, y, X_test=None, cv=5, feval=None, split_random_state=7):
+    def __init__(self, X, y, X_test=None, params=None, cv=5, feval=None, split_random_state=777):
         self.X = X
         self.y = y
         self.X_test = X_test if X_test is not None else self.X[:100]
+        self.params = params
         self.feval = feval
         self.num_classes = len(set(self.y))
 
@@ -59,10 +60,9 @@ class BaseOOF(object):
             self.oof_train = np.argmax(self.oof_train_proba, 1)
             self.oof_test = np.argmax(self.oof_test_proba, 1)
 
-
         if self.feval is not None:
-            score = self.feval(self.y, self.oof_train)
-            print(f"\n\033[94mCV Sorce: {score} ended at {time.ctime()}\033[0m")
+            self.oof_score = self.feval(self.y, self.oof_train)
+            print(f"\n\033[94mCV Sorce: {self.oof_score} ended at {time.ctime()}\033[0m")
 
         if oof_file is not None:
             print("Save OOF Prediction")
