@@ -48,13 +48,13 @@ class SimpleOptimizer(object):
             show_progress_bar=show_progress_bar,
             n_jobs=n_jobs
         )
-        print(f"best_params:\n{json.dumps(self.study.best_params, indent=4)}")
 
         if plot:
+            print(f"best_params:\n{json.dumps(self.study.best_params, indent=4)}")
             return self._plot()
 
     def _plot(self):
-        optuna.visualization.plot_slice(self.study)
+        # optuna.visualization.plot_slice(self.study)
         _ = optuna.visualization.plot_optimization_history(self.study)
 
         # optuna.visualization.plot_param_importances(self.study)
