@@ -10,5 +10,5 @@
 
 from .ModelOptimizer import ModelOptimizer
 from .SimpleOptimizer import SimpleOptimizer
-from .F1Optimizer import F1Optimizer
+from .F1Optimizer_ import F1Optimizer
 from .OptimizedRounderF1 import OptimizedRounderF1
